@@ -7,11 +7,10 @@ Refer to sub-class for typical usage examples.
 """
 from typing import List, Optional
 
-from datacatalogtordf import Resource
-from rdflib import Graph, Namespace, RDF, URIRef
-
-from modelldcatnotordf.agent import Agent
+from datacatalogtordf import Agent, Resource, URI
+from rdflib import BNode, Graph, Namespace, RDF, URIRef
 
+from modelldcatnotordf.modelelement import ModelElement
 
 DCT = Namespace("http://purl.org/dc/terms/")
 DCAT = Namespace("http://www.w3.org/ns/dcat#")
@@ -20,20 +19,33 @@ XSD = Namespace("http://www.w3.org/2001/XMLSchema#")
 PROV = Namespace("http://www.w3.org/ns/prov#")
 MODELLDCATNO = Namespace("https://data.norge.no/vocabulary/modelldcatno#")
 FOAF = Namespace("http://xmlns.com/foaf/0.1/")
+SKOS = Namespace("http://www.w3.org/2004/02/skos/core#")
 
 
 class InformationModel(Resource):
     """A class representing a modelldatno:InformationModel."""
 
-    __slots__ = ("_title", "_type", "_description", "_theme", "_publisher")
+    __slots__ = (
+        "_title",
+        "_type",
+        "_description",
+        "_theme",
+        "_publisher",
+        "_subject",
+        "_modelelements",
+    )
 
     _title: dict
     _publisher: Agent
+    _subject: List[str]
+    _modelelements: List[ModelElement]
 
     def __init__(self) -> None:
         """Inits InformationModel object with default values."""
         super().__init__()
         self._type = MODELLDCATNO.InformationModel
+        self._subject = []
+        self._modelelements = []
 
     @property
     def type(self) -> str:
@@ -76,6 +88,16 @@ class InformationModel(Resource):
     def publisher(self: Resource, publisher: Agent) -> None:
         self._publisher = publisher
 
+    @property
+    def subject(self: Resource) -> URI:
+        """Get/set for subject."""
+        return self._subject
+
+    @property
+    def modelelements(self: Resource) -> List[ModelElement]:
+        """Get/set for modelelements."""
+        return self._modelelements
+
     def to_rdf(
         self: Resource, format: str = "turtle", encoding: Optional[str] = "utf-8",
     ) -> str:
@@ -95,18 +117,6 @@ class InformationModel(Resource):
         """
         return self._to_graph().serialize(format=format, encoding=encoding)
 
-    def unionof(self: Resource, graph: Graph) -> Graph:
-        """Creates a graph union of itself and argument graph.
-
-        Args:
-            graph (Graph): a rdf-lib graph
-
-        Returns:
-            a graph union of itself and argument graph in rdf-lib-format
-        """
-        union = self._g + graph
-        return union
-
     # -
 
     def _to_graph(self: Resource) -> Graph:
@@ -116,16 +126,34 @@ class InformationModel(Resource):
         self._g.add((URIRef(self.identifier), RDF.type, self._type))
 
         self._publisher_to_graph()
+        self._subject_to_graph()
+        self._modelelements_to_graph()
 
         return self._g
 
-    def _publisher_to_graph(self: Resource) -> None:
-        if getattr(self, "publisher", None):
-            self._g.add(
-                (
-                    URIRef(self.identifier),
-                    DCT.publisher,
-                    URIRef(self.publisher.identifier),
+    def _subject_to_graph(self: Resource) -> None:
+        if getattr(self, "subject", None):
+            for subject in self._subject:
+                self._g.add((URIRef(self.identifier), SKOS.Concept, URIRef(subject)))
+
+    def _modelelements_to_graph(self: Resource) -> None:
+
+        if getattr(self, "modelelements", None):
+
+            for modelelement in self._modelelements:
+
+                if getattr(modelelement, "identifier", None):
+                    _modelelement = URIRef(modelelement.identifier)
+                else:
+                    _modelelement = BNode()
+
+                for _s, p, o in modelelement._to_graph().triples((None, None, None)):
+                    self._g.add((_modelelement, p, o))
+
+                self._g.add(
+                    (
+                        URIRef(self.identifier),
+                        MODELLDCATNO.containsModelelement,
+                        _modelelement,
+                    )
                 )
-            )
-            self._g = self.unionof(self.publisher.to_graph())
